import java.io.*;
import java.util.*;
import java.text.*;
import static java.lang.Math.*;

public class petanque
{
    public BufferedReader br;
    public PrintStream ps;

    public LinkedList<Ball> balls;

    public String toString()
    {
        return "petanque";
    }

    public static final double EPSILON = 0.0001;
    public static final double TWOPI = PI+PI;

    boolean eq( double a, double b )
    {
        return abs(a-b) < EPSILON;
    }

    public double normalize( double angle )
    {
        while( angle<0.0 ) angle += TWOPI;
        while( angle>=TWOPI ) angle -= TWOPI;
        return angle;
    }

    public class Ball
    {
        public double x, y;
        public int owner;

        public Ball( int o, double xx, double yy )
        {
            owner = o;
            x = xx;
            y = yy;
        }

        public String toString()
        {
            return "Ball:owner=" + owner + ",x=" + x + ",y=" + y + "}";
        }

        public void toss( double angle, double dist )
        {
            Ball closest = null;
            double leastdist = dist;
            for( Ball b : balls ) if( b!=this )
            {
                if( eq( angle, normalize( atan2( b.y-y, b.x-x ) ) ) )
                {
                    double d = distanceTo( b );
                    if( d<leastdist )
                    {
                        leastdist = d;
                        closest = b;
                    }
                }
            }

            if( closest!=null )
            {
                double xx = closest.x;
                double yy = closest.y;
                closest.toss( angle, dist-leastdist );
                x = xx;
                y = yy;
            }
            else
            {
                x += dist*cos(angle);
                y += dist*sin(angle);
            }
        }

        public double distanceTo( Ball b )
        {
            double dx = x-b.x;
            double dy = y-b.y;
            return sqrt( dx*dx + dy*dy );
        }
    };

    public void doit() throws Exception
    {
        br = new BufferedReader( new FileReader( "petanque.in" ) );
        // br = new BufferedReader( new InputStreamReader( System.in ) );
        ps = new PrintStream( new FileOutputStream( "petanque.sol" ) );
        // ps = System.out;
        int i, j, k;
        String tokens[];

        int nSets = Integer.parseInt( br.readLine().trim() );

        while( nSets-->0 )
        {
            String names[] = br.readLine().trim().split( "\\s+" );

            balls = new LinkedList<Ball>();

            tokens = br.readLine().trim().split( "\\s+" );
            double x = Double.parseDouble( tokens[0] );
            double y = Double.parseDouble( tokens[1] );
            double a = normalize( toRadians( Double.parseDouble( tokens[2] ) ) );
            double d = Double.parseDouble( tokens[3] );

            Ball coche = new Ball( -1, x, y );
            coche.toss( a, d );
            balls.add( coche );

            int owner = 0;
            int remaining[] = {3, 3}; 

            for( i=0; i<6; i++ )
            {
                tokens = br.readLine().trim().split( "\\s+" );
                x = Double.parseDouble( tokens[0] );
                y = Double.parseDouble( tokens[1] );
                a = normalize( toRadians( Double.parseDouble( tokens[2] ) ) );
                d = Double.parseDouble( tokens[3] );

                if( remaining[owner]==0 ) owner = 1-owner;

                Ball boule = new Ball( owner, x, y );
                boule.toss( a, d );
                balls.add( boule );

                --remaining[owner];

                Ball best = null;
                double bestdist = Double.MAX_VALUE;
                for( Ball b : balls ) if( b!=coche )
                {
                    d = b.distanceTo( coche );
                    if( d < bestdist )
                    {
                        bestdist = d;
                        best = b;
                    }
                }

                if( best!=null )
                {
                    owner = 1-best.owner;
                }
                else
                {
                    System.out.println( "best is null!!" );
                }
            }

            double dists[] = { Double.MAX_VALUE, Double.MAX_VALUE };
            for( Ball b : balls ) if( b!=coche )
            {
                d = b.distanceTo( coche );
                if( d<dists[b.owner] ) dists[b.owner] = d;
            }

            int winner = (dists[0]<dists[1])?0:1;
            int score = 0;
            for( Ball b : balls ) if( b!=coche )
            {
                if( b.owner==winner && b.distanceTo(coche)<dists[1-winner] ) ++score;
            }

            ps.println( names[winner] + " " + score );
        }
    }

    public static void main( String args[] ) throws Exception
    {
        (new petanque()).doit();
    }
};
